@@ -46,6 +46,7 @@
 #include <gz/physics/RequestEngine.hh>
 #include <gz/physics/RevoluteJoint.hh>
 #include <gz/physics/Shape.hh>
+#include <gz/physics/World.hh>
 #include <gz/physics/sdf/ConstructModel.hh>
 #include <gz/physics/sdf/ConstructWorld.hh>
 
@@ -948,7 +949,7 @@ TYPED_TEST(JointFeaturesPositionLimitsForceControlTest,
       world->Step(output, state, input);
     }
 
-    // Read wrench from force_torque_status and expect it to be consistent with
+    // Read joint wrench and expect it to be consistent with
     // the dynamic state of the model.
     //
     // Summary of dynamic state at this time in the test:
@@ -1032,6 +1033,221 @@ TYPED_TEST(JointFeaturesPositionLimitsForceControlTest,
   }
 }
 
+struct JointFeatureFrictionList : gz::physics::FeatureList<
+    gz::physics::ForwardStep,
+    gz::physics::GetBasicJointProperties,
+    gz::physics::GetBasicJointState,
+    gz::physics::GetEngineInfo,
+    gz::physics::GetJointFromModel,
+    gz::physics::GetModelFromWorld,
+    gz::physics::SetBasicJointState,
+    gz::physics::SetJointFrictionFeature,
+    gz::physics::sdf::ConstructSdfWorld
+> { };
+
+template <class T>
+class JointFeaturesFrictionTest :
+  public JointFeaturesTest<T>{};
+using JointFeaturesFrictionTestTypes =
+  ::testing::Types<JointFeatureFrictionList>;
+TYPED_TEST_SUITE(JointFeaturesFrictionTest,
+                 JointFeaturesFrictionTestTypes);
+
+TYPED_TEST(JointFeaturesFrictionTest, JointSetSpringStiffness)
+{
+  for (const std::string &name : this->pluginNames)
+  {
+    if(this->PhysicsEngineName(name) != "dartsim")
+    {
+      GTEST_SKIP();
+    }
+
+    std::cout << "Testing plugin: " << name << std::endl;
+    gz::plugin::PluginPtr plugin = this->loader.Instantiate(name);
+
+    auto engine =
+      gz::physics::RequestEngine3d<JointFeatureFrictionList>::From(plugin);
+    ASSERT_NE(nullptr, engine);
+
+    sdf::Root root;
+    const sdf::Errors errors = root.Load(common_test::worlds::kTestWorld);
+    ASSERT_TRUE(errors.empty()) << errors.front();
+
+    auto world = engine->ConstructWorld(*root.WorldByIndex(0));
+    auto model = world->GetModel("pendulum_with_base");
+    auto joint = model->GetJoint("upper_joint");
+
+    gz::physics::ForwardStep::Output output;
+    gz::physics::ForwardStep::State state;
+    gz::physics::ForwardStep::Input input;
+
+    world->Step(output, state, input);
+
+    joint->SetPosition(0, -GZ_PI/2);
+
+    // default friction value is zero
+    // so oscillations are expected
+    for (std::size_t i = 0; i < 100; ++i)
+    {
+      world->Step(output, state, input);
+    }
+    EXPECT_LT(joint->GetPosition(0), -1.54);
+    EXPECT_LT(joint->GetVelocity(0), 1e-2);
+
+    // setting very high friction value
+    // pendulum shouldn't move much (expected)
+    joint->SetPosition(0, -GZ_PI/2);
+    ASSERT_EQ(joint->GetPosition(0), -GZ_PI/2);
+
+    joint->SetVelocity(0, 1);
+    ASSERT_EQ(joint->GetVelocity(0), 1);
+    joint->SetFriction(0, 100);
+
+    // running simulation for longer to make sure
+    // joint position doesn't change (expected)
+    for (std::size_t i = 0; i < 1000; ++i)
+    {
+      world->Step(output, state, input);
+    }
+
+    auto joint_pos1 = joint->GetPosition(0);
+
+    EXPECT_NEAR(0, joint->GetVelocity(0), 1e-10);
+
+    // setting some moderate value of joint friction
+    joint->SetPosition(0, -GZ_PI/2);
+    ASSERT_EQ(joint->GetPosition(0), -GZ_PI/2);
+
+    joint->SetVelocity(0, 1);
+    ASSERT_EQ(joint->GetVelocity(0), 1);
+
+    joint->SetFriction(0, 5);
+
+    for (std::size_t i = 0; i < 500; ++i)
+    {
+      world->Step(output, state, input);
+    }
+
+    auto joint_pos2 = joint->GetPosition(0);
+
+    // with good enough simulation time for moderate
+    // value of friction, joint position should converge
+    // to zero (expected)
+    EXPECT_LT(joint->GetVelocity(0), 1e-5);
+    EXPECT_LT(joint_pos1, joint_pos2 + 0.1);
+  }
+}
+
+struct JointFeatureSpringStiffnessList : gz::physics::FeatureList<
+    gz::physics::ForwardStep,
+    gz::physics::GetBasicJointProperties,
+    gz::physics::GetBasicJointState,
+    gz::physics::GetEngineInfo,
+    gz::physics::GetJointFromModel,
+    gz::physics::Gravity,
+    gz::physics::GetModelFromWorld,
+    gz::physics::SetBasicJointState,
+    gz::physics::SetJointSpringStiffnessFeature,
+    gz::physics::SetJointSpringReferenceFeature,
+    gz::physics::SetJointDampingCoefficientFeature,
+    gz::physics::sdf::ConstructSdfWorld
+> { };
+
+template <class T>
+class JointFeaturesSpringStiffnessTest :
+  public JointFeaturesTest<T>{};
+using JointFeaturesSpringStiffnessTestTypes =
+  ::testing::Types<JointFeatureSpringStiffnessList>;
+TYPED_TEST_SUITE(JointFeaturesSpringStiffnessTest,
+                 JointFeaturesSpringStiffnessTestTypes);
+
+TYPED_TEST(JointFeaturesSpringStiffnessTest, JointSetSpringStiffness)
+{
+  for (const std::string &name : this->pluginNames)
+  {
+    if(this->PhysicsEngineName(name) != "dartsim")
+    {
+      GTEST_SKIP();
+    }
+
+    std::cout << "Testing plugin: " << name << std::endl;
+    gz::plugin::PluginPtr plugin = this->loader.Instantiate(name);
+
+    auto engine =
+      gz::physics::RequestEngine3d<JointFeatureSpringStiffnessList>::From(plugin);
+    ASSERT_NE(nullptr, engine);
+
+    sdf::Root root;
+    const sdf::Errors errors = root.Load(common_test::worlds::kTestWorld);
+    ASSERT_TRUE(errors.empty()) << errors.front();
+
+    auto world = engine->ConstructWorld(*root.WorldByIndex(0));
+    auto model = world->GetModel("pendulum_with_base");
+    auto joint = model->GetJoint("upper_joint");
+
+    gz::physics::ForwardStep::Output output;
+    gz::physics::ForwardStep::State state;
+    gz::physics::ForwardStep::Input input;
+
+    // turning off gravity so that the system behaves
+    // like mass-damper
+    world->SetGravity(Eigen::Vector3d::Zero());
+
+    world->Step(output, state, input);
+    // setting joint position to start from the bottom
+    // pendulum position
+    joint->SetPosition(0, GZ_PI/2);
+    ASSERT_EQ(joint->GetPosition(0), GZ_PI/2);
+
+    // setting joint velocity to zero
+    joint->SetVelocity(0, 0);
+    ASSERT_EQ(joint->GetVelocity(0), 0);
+    // setting joint velocity to zero
+    joint->SetVelocity(0, 0);
+    ASSERT_EQ(joint->GetVelocity(0), 0);
+    // without reference joint position joint should stay
+    // at GZ_PI/2
+    for (std::size_t i = 0; i < 2500; ++i)
+    {
+      world->Step(output, state, input);
+    }
+
+    // checking if the link has moved
+    ASSERT_NEAR(joint->GetPosition(0), GZ_PI/2, 1e-5);
+    ASSERT_NEAR(joint->GetVelocity(0), 0, 1e-5);
+
+    // resetting joint position and velocity
+    joint->SetPosition(0, GZ_PI/2);
+    ASSERT_EQ(joint->GetPosition(0), GZ_PI/2);
+
+    joint->SetVelocity(0, 0);
+    ASSERT_EQ(joint->GetVelocity(0), 0);
+
+    // setting joint rest position to pendulum upright position
+    joint->SetSpringReference(0, -GZ_PI/2);
+
+    // setting joint stiffness
+    joint->SetSpringStiffness(0, 60);
+
+    // setting joint damping to stabilize the joint's
+    // rest position
+    joint->SetDampingCoefficient(0, 17);
+
+    // running simulation for longer to make sure
+    // joint reaches equilibrium
+    for (std::size_t i = 0; i < 2500; ++i)
+    {
+      world->Step(output, state, input);
+    }
+
+    // checking if the joint position is the same
+    // as rest position
+    ASSERT_NEAR(joint->GetPosition(0), -GZ_PI/2, 1e-4);
+
+    // checking if the link has reached equilibrium
+    ASSERT_NEAR(joint->GetVelocity(0), 0, 1e-5);
+  }
+}
 ///////////// DARTSIM > 6.10 end
 
 
@@ -1176,8 +1392,8 @@ TYPED_TEST(JointFeaturesDetachTest, JointDetach)
     // sanity check on velocity values
     EXPECT_LT(1e-5, upperLinkLinearVelocity.Z());
     EXPECT_GT(-0.03, upperLinkAngularVelocity.X());
-#ifdef __APPLE__
-    // Disable some expectations for dartsim plugin on homebrew,
+#ifdef DART_ODE_CCD_WITH_BOX_CYLINDER_COLLISION
+    // Disable some expectations for dartsim plugin with ode version >= 0.16.5,
     // see https://github.com/gazebosim/gz-physics/issues/620.
     if (this->PhysicsEngineName(name) != "dartsim")
 #endif
@@ -1185,8 +1401,8 @@ TYPED_TEST(JointFeaturesDetachTest, JointDetach)
       EXPECT_NEAR(0.0, upperLinkLinearVelocity.X(), 1e-6);
     }
     EXPECT_NEAR(0.0, upperLinkLinearVelocity.Y(), 1e-6);
-#ifdef __APPLE__
-    // Disable some expectations for dartsim plugin on homebrew,
+#ifdef DART_ODE_CCD_WITH_BOX_CYLINDER_COLLISION
+    // Disable some expectations for dartsim plugin with ode version >= 0.16.5,
     // see https://github.com/gazebosim/gz-physics/issues/620.
     if (this->PhysicsEngineName(name) != "dartsim")
 #endif
@@ -2334,6 +2550,156 @@ TEST_F(FixedJointFreeGroupFeatureTestTypes, FixedJointFreeGroupMove)
   }
 }
 
+using FixedJointWeldFeatureList = gz::physics::FeatureList<
+    gz::physics::FindFreeGroupFeature,
+    gz::physics::SetFreeGroupWorldPose,
+    gz::physics::AttachFixedJointFeature,
+    gz::physics::DetachJointFeature,
+    gz::physics::ForwardStep,
+    gz::physics::GetBasicJointProperties,
+    gz::physics::GetBasicJointState,
+    gz::physics::GetEngineInfo,
+    gz::physics::GetJointFromModel,
+    gz::physics::GetLinkFromModel,
+    gz::physics::GetModelFromWorld,
+    gz::physics::LinkFrameSemantics,
+    gz::physics::SetBasicJointState,
+    gz::physics::SetFixedJointWeldChildToParentFeature,
+    gz::physics::SetJointTransformFromParentFeature,
+    gz::physics::SetJointVelocityCommandFeature,
+    gz::physics::sdf::ConstructSdfModel,
+    gz::physics::sdf::ConstructSdfWorld
+>;
+
+using FixedJointWeldFeatureTestTypes =
+  JointFeaturesTest<FixedJointWeldFeatureList>;
+
+TEST_F(FixedJointWeldFeatureTestTypes, FixedJointWeldFall)
+{
+  // Attach joint between links from 2 models (M1 and M2) with a fixed joint.
+  // Let them fall and the child model (M2) should collide with a third model
+  // (body).
+  // Run the test once without welding child to parent then run again
+  // with welding enabled. Verify that the fixed joint enforces the relative
+  // pose between the parent and child links but there should still be some
+  // position error. Verify that the welded joint has a smaller error.
+  for (const std::string &name : this->pluginNames)
+  {
+    std::cout << "Testing plugin: " << name << std::endl;
+    gz::plugin::PluginPtr plugin = this->loader.Instantiate(name);
+
+    auto engine =
+        gz::physics::RequestEngine3d<FixedJointWeldFeatureList>::From(
+        plugin);
+    ASSERT_NE(nullptr, engine);
+
+    sdf::Root root;
+    const sdf::Errors errors = root.Load(common_test::worlds::kJointAcrossModelsSdf);
+    ASSERT_TRUE(errors.empty()) << errors.front();
+
+    auto world = engine->ConstructWorld(*root.WorldByIndex(0));
+
+    const std::string modelName1{"M1"};
+    const std::string modelName2{"M2"};
+    const std::string bodyName{"body"};
+
+    auto model1 = world->GetModel(modelName1);
+    auto model2 = world->GetModel(modelName2);
+    auto body = world->GetModel(bodyName);
+    auto model1Body = model1->GetLink(bodyName);
+    auto model2Body = model2->GetLink(bodyName);
+
+    // \todo(iche033) Extend test to use pose with rotations and
+    // verify that the relative pose between parent and child entities
+    // are enforced.
+    const gz::math::Pose3d model1Pose(0, -1, 1.0, 0, 0, 0.0);
+    const gz::math::Pose3d model2Pose(0, 1, 1.0, 0, 0, 0.0);
+    const gz::math::Pose3d bodyPose(0, 1, 0.25, 0, 0, 0.0);
+    auto freeGroupM1 = model1->FindFreeGroup();
+    auto freeGroupM2 = model2->FindFreeGroup();
+    auto freeGroupBody = body->FindFreeGroup();
+    freeGroupM1->SetWorldPose(gz::math::eigen3::convert(model1Pose));
+    freeGroupM2->SetWorldPose(gz::math::eigen3::convert(model2Pose));
+    freeGroupBody->SetWorldPose(gz::math::eigen3::convert(bodyPose));
+
+    auto frameDataModel1Body = model1Body->FrameDataRelativeToWorld();
+    auto frameDataModel2Body = model2Body->FrameDataRelativeToWorld();
+
+    EXPECT_EQ(model1Pose,
+              gz::math::eigen3::convert(frameDataModel1Body.pose));
+    EXPECT_EQ(model2Pose,
+              gz::math::eigen3::convert(frameDataModel2Body.pose));
+
+    gz::physics::ForwardStep::Output output;
+    gz::physics::ForwardStep::State state;
+    gz::physics::ForwardStep::Input input;
+
+    const std::size_t numSteps = 500;
+
+    // Attach fixed joint
+    auto poseParent = frameDataModel1Body.pose;
+    auto poseChild = frameDataModel2Body.pose;
+    auto poseParentChild = poseParent.inverse() * poseChild;
+    auto fixedJoint = model2Body->AttachFixedJoint(model1Body);
+    fixedJoint->SetTransformFromParent(poseParentChild);
+
+    // Run once without welding child to parent
+    fixedJoint->SetWeldChildToParent(false);
+
+    gz::math::Pose3d gzPoseParentChild =
+        gz::math::eigen3::convert(poseParentChild);
+    double errNoWeld = 0.0;
+    for (std::size_t i = 0; i < numSteps; ++i)
+    {
+      world->Step(output, state, input);
+
+      frameDataModel1Body = model1Body->FrameDataRelativeToWorld();
+      frameDataModel2Body = model2Body->FrameDataRelativeToWorld();
+
+      auto newPoseParent = frameDataModel1Body.pose;
+      auto newPoseChild = frameDataModel2Body.pose;
+      auto newPoseParentChild = newPoseParent.inverse() * newPoseChild;
+      gz::math::Pose3d gzNewPoseParentChild =
+          gz::math::eigen3::convert(newPoseParentChild);
+      // The relative parent-child pose should still be enforced even without
+      // welding the child to parent but record the pos error
+      EXPECT_EQ(gzPoseParentChild, gzNewPoseParentChild);
+      errNoWeld +=
+          (gzNewPoseParentChild.Pos() - gzPoseParentChild.Pos()).Length();
+    }
+
+    // Reset model poses
+    freeGroupM1->SetWorldPose(gz::math::eigen3::convert(model1Pose));
+    freeGroupM2->SetWorldPose(gz::math::eigen3::convert(model2Pose));
+    freeGroupBody->SetWorldPose(gz::math::eigen3::convert(bodyPose));
+
+
+    // Run the test with child welded to parent
+    fixedJoint->SetWeldChildToParent(true);
+    double errWeld = 0.0;
+    for (std::size_t i = 0; i < numSteps; ++i)
+    {
+      world->Step(output, state, input);
+
+      frameDataModel1Body = model1Body->FrameDataRelativeToWorld();
+      frameDataModel2Body = model2Body->FrameDataRelativeToWorld();
+
+      auto newPoseParent = frameDataModel1Body.pose;
+      auto newPoseChild = frameDataModel2Body.pose;
+      auto newPoseParentChild = newPoseParent.inverse() * newPoseChild;
+      gz::math::Pose3d gzNewPoseParentChild =
+          gz::math::eigen3::convert(newPoseParentChild);
+      // The relative parent-child pose should be enforced but record the pos
+      // error
+      EXPECT_EQ(gzPoseParentChild, gzNewPoseParentChild);
+      errWeld +=
+          (gzNewPoseParentChild.Pos() - gzPoseParentChild.Pos()).Length();
+    }
+    // Verify that the error is smaller when child is welded to parent
+    EXPECT_LT(errWeld, errNoWeld);
+  }
+}
+
 int main(int argc, char *argv[])
 {
   ::testing::InitGoogleTest(&argc, argv);
