@@ -447,9 +447,6 @@ TEST_P(SimulationFeatures_TEST, FreeGroup)
     auto model = world->GetModel("sphere");
     auto freeGroup = model->FindFreeGroup();
     ASSERT_NE(nullptr, freeGroup);
-    GZ_UTILS_WARN_IGNORE__DEPRECATED_DECLARATION
-    ASSERT_NE(nullptr, freeGroup->CanonicalLink());
-    GZ_UTILS_WARN_RESUME__DEPRECATED_DECLARATION
     ASSERT_NE(nullptr, freeGroup->RootLink());
 
     auto link = model->GetLink("sphere_link");
